import axios from 'axios';

var Markup = /** @class */ (function () {
    function Markup(json) {
        this.type = json.type;
        this.start = json.start;
        this.end = json.end;
        this.href = json.href;
    }
    Object.defineProperty(Markup.prototype, "open", {
        get: function () {
            switch (this.type) {
                case MarkupType.Bold:
                    return "**";
                case MarkupType.Italic:
                    return "*";
                case MarkupType.Anchor:
                    return "[";
                default:
                    throw new Error("Unknown markup type \"" + this.type + "\".");
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Markup.prototype, "close", {
        get: function () {
            switch (this.type) {
                case MarkupType.Bold:
                    return '**';
                case MarkupType.Italic:
                    return '*';
                case MarkupType.Anchor:
                    return "](" + this.href + ")";
                default:
                    throw new Error("Unknown markup type \"" + this.type + "\".");
            }
        },
        enumerable: true,
        configurable: true
    });
    return Markup;
}());
var MarkupType;
(function (MarkupType) {
    MarkupType[MarkupType["Bold"] = 1] = "Bold";
    MarkupType[MarkupType["Italic"] = 2] = "Italic";
    MarkupType[MarkupType["Anchor"] = 3] = "Anchor";
})(MarkupType || (MarkupType = {}));

var MEDIUM_IMG_CDN = 'https://cdn-images-1.medium.com';
var MEDIUM_MEDIA = 'https://medium.com/media';
var Paragraph = /** @class */ (function () {
    /**
     * @param  {string} publicname
     * @param  {number} publictype
     * @param  {string} publictext
     * @param  {Markup[]} publicmarkups
     */
    function Paragraph(json) {
        this.type = setParagraphType(json.type);
        this.name = json.name;
        this.markups = json.markups ? json.markups.map(function (m) { return new Markup(m); }) : []; // eslint-disable-line
        this.text = json.text;
        this.metadata = json.metadata;
        this.iframe = json.iframe;
    }
    Paragraph.prototype.processParagraph = function () {
        var markups = createMarkupArray(this.markups);
        var parsedText = this.text;
        if (markups.length > 0) {
            var previousIndex = 0;
            var text = this.text;
            var tokens = [];
            for (var j = 0; j < markups.length; j++) {
                if (markups[j]) {
                    var token = text.substring(previousIndex, j);
                    previousIndex = j;
                    tokens.push(token);
                    tokens.push(markups[j]);
                }
            }
            tokens.push(text.substring(markups.length - 1));
            parsedText = tokens.join('');
        }
        return this.addParagraphMarkup(parsedText);
    };
    Paragraph.prototype.addParagraphMarkup = function (parsedText) {
        var text;
        switch (this.type) {
            case ParagraphType.Standard:
                text = "\n " + parsedText;
                break;
            case ParagraphType.H1:
                text = "\n# " + parsedText.replace(/\n/g, '\n# ');
                break;
            case ParagraphType.ImageAndCaption:
                var imgsrc = MEDIUM_IMG_CDN;
                if (this.metadata.originalHeight) {
                    imgsrc = imgsrc + "/fit/" + this.metadata.originalWidth + "/" + this.metadata.originalHeight + "/" + this.metadata.id;
                }
                else {
                    imgsrc = imgsrc + "/max/" + this.metadata.originalWidth + "/" + this.metadata.id;
                }
                text = "\n![" + parsedText + "](" + imgsrc + ")";
                if (parsedText) {
                    text += "*" + parsedText + "*";
                }
                break;
            case ParagraphType.BlockQuote:
                text = "\n> " + parsedText;
                break;
            case ParagraphType.Code:
                text = "```\n " + parsedText + "```";
                break;
            case ParagraphType.UnOrderedList:
                text = "\n* " + parsedText;
                break;
            case ParagraphType.OrderedList:
                text = "\n1. " + parsedText;
                break;
            case ParagraphType.IFrame:
                // TODO: use youtube videos if they have it
                var iframeSrc = MEDIUM_MEDIA + "/" + this.iframe.mediaResourceId;
                // text = `[![${parsedText}](${MEDIUM_MEDIA}/${this.iframe.mediaResourceId}/0.jpg)](http://www.youtube.com/watch?v=YOUTUBE_VIDEO_ID_HERE)`
                text = "<iframe src=\"" + iframeSrc + "\" frameborder=0></iframe>";
                break;
            case ParagraphType.SubTitle:
                text = "\n### " + parsedText;
                break;
        }
        return "\n" + text;
    };
    return Paragraph;
}());
function createMarkupArray(markups) {
    var array = [];
    markups.map(function (m) {
        if (array[m.start]) {
            array[m.start] += m.open;
        }
        else {
            array[m.start] = m.open;
        }
        if (array[m.end]) {
            if (m.type === MarkupType.Anchor) {
                array[m.end] += array[m.end];
            }
            else {
                array[m.end] = m.close + array[m.end];
            }
        }
        else {
            array[m.end] = m.close;
        }
    });
    return array;
}
function setParagraphType(type) {
    switch (type) {
        case 1:
            return ParagraphType.Standard;
        case 2:
        case 3:
            return ParagraphType.H1;
        case 4:
            return ParagraphType.ImageAndCaption;
        case 6:
            return ParagraphType.BlockQuote;
        case 8:
            return ParagraphType.Code;
        case 9:
            return ParagraphType.UnOrderedList;
        case 10:
            return ParagraphType.OrderedList;
        case 11:
            return ParagraphType.IFrame;
        case 13:
            return ParagraphType.SubTitle;
        default:
            throw new Error("Unknown paragraph type \"" + type + "\" encountered.");
    }
}
var ParagraphType;
(function (ParagraphType) {
    ParagraphType[ParagraphType["Standard"] = 1] = "Standard";
    ParagraphType[ParagraphType["H1"] = 2] = "H1";
    ParagraphType[ParagraphType["ImageAndCaption"] = 3] = "ImageAndCaption";
    ParagraphType[ParagraphType["BlockQuote"] = 4] = "BlockQuote";
    ParagraphType[ParagraphType["Code"] = 5] = "Code";
    ParagraphType[ParagraphType["UnOrderedList"] = 6] = "UnOrderedList";
    ParagraphType[ParagraphType["IFrame"] = 7] = "IFrame";
    ParagraphType[ParagraphType["SubTitle"] = 8] = "SubTitle";
    ParagraphType[ParagraphType["OrderedList"] = 9] = "OrderedList";
})(ParagraphType || (ParagraphType = {}));

var Story = /** @class */ (function () {
    /**
     * @param  {LooseObject} json
     */
    function Story(json) {
        this.updatedAt = new Date(json.updatedAt);
        this.createdAt = new Date(json.createdAt);
        this.content = new Content(json.content.subtitle, json.content.bodyModel.paragraphs);
        this.id = json.id;
        this.title = json.title;
        this.detectedLanguage = json.detectedLanguage;
    }
    return Story;
}());
var Content = /** @class */ (function () {
    /**
     * @param  {String} publicsubtitle
     * @param  {LooseObject[]} paragraphs
     */
    function Content(subtitle, paragraphs) {
        this.subtitle = subtitle;
        this.paragraphs = paragraphs.map(function (p) { return new Paragraph(p); });
    }
    Content.prototype.toMarkdown = function () {
        return this.paragraphs.reduce(function (p, v) { return (p += v.processParagraph()); }, '');
    };
    return Content;
}());

var default_1 = /** @class */ (function () {
    function default_1(json) {
        this.posts = json.posts.map(function (p) { return new Post(p.uniqueSlug, p.title); });
    }
    return default_1;
}());
var Post = /** @class */ (function () {
    /**
     *
     */
    function Post(uniqueSlug, title) {
        this.uniqueSlug = uniqueSlug;
        this.title = title;
    }
    return Post;
}());

/**
 * @param  {string} rawPost
 * @returns string
 */
function cleanResponse(rawPost) {
    var result = rawPost.substr(rawPost.indexOf('{'));
    return result;
}
/**
 * @param  {string} cleanedPost
 * @returns Object, in json formatt
 */
function getValue(cleanedPost) {
    var result = JSON.parse(cleanedPost).payload.value;
    return result;
}

var MEDIUM_URL = 'https://medium.com';
var FORMAT = 'format=json';
function getStory(mediumUserName, storyId) {
    return axios
        .get(MEDIUM_URL + "/" + mediumUserName + "/" + storyId + "?" + FORMAT)
        .then(function (response) {
        var cleanedPost = cleanResponse(response.data);
        var value = getValue(cleanedPost);
        return new Story(value);
    });
}
function getLatest(mediumUserName) {
    return axios
        .get(MEDIUM_URL + "/" + mediumUserName + "/latest?" + FORMAT)
        .then(function (response) {
        var cleanedPost = cleanResponse(response.data);
        var json = JSON.parse(cleanedPost).payload;
        return new default_1(json);
    });
}

export { getStory, getLatest };
//# sourceMappingURL=node-medium-feed.es5.js.map
